==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_fields/DATAFLOWSTUDIOMAPPINGID_Type.java <==

package net.datastream.schemas.mp_fields;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for DATAFLOWSTUDIOMAPPINGID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="DATAFLOWSTUDIOMAPPINGID_Type">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}MESSAGEID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}DATAFLOWSTUDIOFLOWFILEUUID"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "DATAFLOWSTUDIOMAPPINGID_Type", propOrder = {
    "messageid",
    "dataflowstudioflowfileuuid"
})
public class DATAFLOWSTUDIOMAPPINGID_Type {

    @XmlElement(name = "MESSAGEID", required = true)
    protected String messageid;
    @XmlElement(name = "DATAFLOWSTUDIOFLOWFILEUUID", required = true)
    protected String dataflowstudioflowfileuuid;

    /**
     * Gets the value of the messageid property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMESSAGEID() {
        return messageid;
    }

    /**
     * Sets the value of the messageid property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMESSAGEID(String value) {
        this.messageid = value;
    }

    /**
     * Gets the value of the dataflowstudioflowfileuuid property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDATAFLOWSTUDIOFLOWFILEUUID() {
        return dataflowstudioflowfileuuid;
    }

    /**
     * Sets the value of the dataflowstudioflowfileuuid property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDATAFLOWSTUDIOFLOWFILEUUID(String value) {
        this.dataflowstudioflowfileuuid = value;
    }

}

==> eam-wshub-proxyclient-12.1-3-sources.jar: net/datastream/schemas/mp_fields/DATAFLOWSTUDIOMAPPINGID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for DATAFLOWSTUDIOMAPPINGID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="DATAFLOWSTUDIOMAPPINGID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MESSAGEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DATAFLOWSTUDIOFLOWFILEUUID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "DATAFLOWSTUDIOMAPPINGID_Type", propOrder = {
    "messageid",
    "dataflowstudioflowfileuuid"
})
public class DATAFLOWSTUDIOMAPPINGID_Type {

    @XmlElement(name = "MESSAGEID", required = true)
    protected String messageid;
    @XmlElement(name = "DATAFLOWSTUDIOFLOWFILEUUID", required = true)
    protected String dataflowstudioflowfileuuid;

    /**
     * Gets the value of the messageid property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMESSAGEID() {
        return messageid;
    }

    /**
     * Sets the value of the messageid property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMESSAGEID(String value) {
        this.messageid = value;
    }

    /**
     * Gets the value of the dataflowstudioflowfileuuid property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDATAFLOWSTUDIOFLOWFILEUUID() {
        return dataflowstudioflowfileuuid;
    }

    /**
     * Sets the value of the dataflowstudioflowfileuuid property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDATAFLOWSTUDIOFLOWFILEUUID(String value) {
        this.dataflowstudioflowfileuuid = value;
    }

}
